import logging  # isort:skip
import colorlog  # isort:skip

handler = colorlog.StreamHandler()
handler.setFormatter(
    colorlog.ColoredFormatter("%(log_color)s%(levelname)s:%(name)s:%(message)s")
)
logging.basicConfig(level=logging.WARNING, handlers=(handler,))

from argparse import ArgumentParser

from . import PACKAGE_NAME, commands
from .opts import DEFAULT_CONFIG_PATHS, Config

parser = ArgumentParser(
    prog=PACKAGE_NAME,
    description=f"{PACKAGE_NAME} - tools for checking Salt state validity",
)
parser.add_argument(
    "-c",
    "--config",
    help=f"path to {PACKAGE_NAME} configuration file (default: {' or '.join(DEFAULT_CONFIG_PATHS)})",
)
parser.set_defaults(func=lambda _: parser.print_usage())
subparsers = parser.add_subparsers(title="commands")

highstate_parser = subparsers.add_parser(
    "highstate", help="renders the states for the specified minions"
)
highstate_parser.add_argument("minion_id", nargs="*")
highstate_parser.set_defaults(func=commands.highstate)

pillars_parser = subparsers.add_parser(
    "pillars", help="renders pillar items for the specified minions"
)
pillars_parser.add_argument("minion_id", nargs="*")
pillars_parser.set_defaults(func=commands.pillars)

refresh_parser = subparsers.add_parser(
    "refresh", help="invoke saltutil.sync_all runner"
)
refresh_parser.set_defaults(func=commands.refresh)

args = parser.parse_args()
config = Config(args)
args.func(config)



import sys
from unittest.mock import patch

import salt.output
import salt.runners.saltutil
from salt.fileserver import Fileserver

from . import pillar, state
from .opts import Config


def highstate(config: Config):
    highstate = state.show_highstate(config)

    output = {minion_id: result.value for minion_id, result in highstate.items()}
    _display_output(output, config)

    if not all(r.valid for r in highstate.values()):
        sys.exit(1)


def pillars(config: Config):
    result = pillar.items(config)
    _display_output(result, config)

    if any("_errors" in pillar for pillar in result.values()):
        sys.exit(1)


def refresh(config: Config):
    with patch("salt.runners.saltutil.__opts__", config.opts, create=True):
        salt.runners.saltutil.sync_all()


def _display_output(output: dict, config: Config):
    salt.output.display_output(output, out="yaml", opts=config.opts)



import salt.output
import salt.pillar

from .opts import Config


def items(config: Config) -> dict:
    return {
        minion_id: compile_pillar(
            opts=config.opts, grains=config.grains_for(minion_id), minion_id=minion_id
        )
        for minion_id in config.minion_ids
    }


def compile_pillar(opts: dict, grains: dict, minion_id: str) -> dict:
    return salt.pillar.get_pillar(opts, grains, minion_id).compile_pillar()
